"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
var path = require("path");
var fs = require("fs");
var url = require("url");
var log = require("electron-log");
var preload = require("./preload");
if (process.platform == "linux") {
    var BASE_PATH = path.join(process.env.HOME, "Documents/FM332Log");
}
else if (process.platform == "darwin") {
    var BASE_PATH = path.join(process.env.HOME, "Documents/FM332Log");
    //var BASE_PATH = process.env.PWD;    
}
else {
    var BASE_PATH = process.env.PORTABLE_EXECUTABLE_DIR;
}
if (BASE_PATH == null) {
    BASE_PATH = __dirname;
}
var d = new Date(), month = '' + (d.getMonth() + 1), day = '' + d.getDate(), year = d.getFullYear();
if (month.length < 2)
    month = '0' + month;
if (day.length < 2)
    day = '0' + day;
var fileNameLog = [year, month, day].join('-') + "_log.log";
log.transports.file.resolvePath = function () { return BASE_PATH + "/logs/" + fileNameLog; };
log.transports.file.maxSize = 1024 * 1024 * 10;
//Il faut nettoyer les logs trop vieux
var testFolder = BASE_PATH + "/logs/";
fs.readdir(testFolder, function (err, files) {
    if (files) {
        files.forEach(function (file) {
            //On va chercher les fichiers vieux de plus de 15 jours
            var y_file = file.substring(0, 4);
            var m_file = file.substring(5, 7);
            var d_file = file.substring(8, 10);
            var date = new Date();
            date.setFullYear(parseInt(y_file));
            date.setMonth(parseInt(m_file) - 1);
            date.setDate(parseInt(d_file));
            var today = new Date();
            if (today.getTime() - date.getTime() > 30 * 24 * 60 * 60 * 1000) { //On vire les fichiers de plus d'un mois
                fs.unlinkSync(BASE_PATH + "/logs/" + file);
            }
        });
    }
});
// Initialize remote module
require('@electron/remote/main').initialize();
var win = null;
var args = process.argv.slice(1), serve = args.some(function (val) { return val === '--serve'; });
function createWindow() {
    var electronScreen = electron_1.screen;
    var size = electronScreen.getPrimaryDisplay().workAreaSize;
    // Create the browser window.
    win = new electron_1.BrowserWindow({
        width: 1200,
        height: 700,
        minHeight: 700,
        minWidth: 1200,
        // maxHeight:600,
        // maxWidth:1200,
        webPreferences: {
            nodeIntegration: true,
            allowRunningInsecureContent: (serve) ? true : false,
            contextIsolation: false,
            enableRemoteModule: true,
            preload: path.join(__dirname, 'preload.js'),
        },
        icon: path.join(__dirname, '../src/assets/icons/favicon.ico')
    });
    // Remove menubar
    win.setMenuBarVisibility(false);
    if (serve) {
        // win.webContents.openDevTools();
        require('electron-reload')(__dirname, {
            electron: path.join(__dirname, '../node_modules', '.bin', 'electron'),
            hardResetMethod: 'exit'
        });
        win.loadURL('http://localhost:4200');
    }
    else {
        // Path when running electron executable
        var pathIndex = './index.html';
        if (fs.existsSync(path.join(__dirname, '../dist/index.html'))) {
            // Path when running electron in local folder
            pathIndex = '../dist/index.html';
        }
        win.loadURL(url.format({
            pathname: path.join(__dirname, pathIndex),
            protocol: 'file:',
            slashes: true
        }));
    }
    // Emitted when the window is closed.
    win.on('closed', function () {
        // Dereference the window object, usually you would store window
        // in an array if your app supports multi windows, this is the time
        // when you should delete the corresponding element.
        clearInterval(tUnplugged);
        win = null;
    });
    win.webContents.on('did-finish-load', function () {
        log.info("DID FINISH LOAD");
        var name = require('./package.json').name;
        var version = require('./package.json').version;
        var windowtitle = name + " " + version;
        win.setTitle(windowtitle);
    });
    return win;
}
try {
    // This method will be called when Electron has finished
    // initialization and is ready to create browser windows.
    // Some APIs can only be used after this event occurs.
    // Added 400 ms to fix the black background issue while using transparent window. More detais at https://github.com/electron/electron/issues/15947
    electron_1.app.commandLine.appendSwitch('--no-sandbox');
    electron_1.app.on('ready', function () { return setTimeout(createWindow, 400); });
    // app.whenReady().then(() => {
    //   createWindow();
    // })
    // Quit when all windows are closed.
    electron_1.app.on('window-all-closed', function () {
        // On OS X it is common for applications and their menu bar
        // to stay active until the user quits explicitly with Cmd + Q
        if (process.platform !== 'darwin') {
            electron_1.app.quit();
        }
    });
    electron_1.app.on('activate', function () {
        // On OS X it's common to re-create a window in the app when the
        // dock icon is clicked and there are no other windows open.
        if (win === null) {
            createWindow();
        }
    });
    electron_1.app.allowRendererProcessReuse = false;
    electron_1.ipcMain.on('data-ready', function (event, arg) {
        log.info("IPCMAIN BEGIN DATA ");
        beginGetData();
    });
    electron_1.ipcMain.on('get-data-flash', function (event, arg) {
        //console.log("dans ipc main get data flash")
        // log.info("IPCMAIN GET DATA FLASH")
        getDataFlash();
    });
    electron_1.ipcMain.on('get-vars-home', function (event, arg) {
        log.info("IPCMAIN GET VARS");
        var preloadVars;
        if (preload.getBprIsUnplugged().bBprUnplugged) {
            preloadVars = { 'comPort': null,
                'numBpr': "0",
                'dateBpr': null };
        }
        else {
            preloadVars = preload.getVars();
        }
        if (win !== null)
            win.webContents.send('get-vars-preload', preloadVars);
    });
    //check if bpr is unplugged while getting data
    var tUnplugged = setInterval(function () {
        var preloadVars;
        if (bIsRunning === true) {
            // console.log("is running de unplugged !!")
            // console.log("bpr unplugged dans settimeout main tUnplugged: ",preload.getBprIsUnplugged().bBprUnplugged)
            if (preload.getBprIsUnplugged().bBprUnplugged) {
                log.info("BPR Unplugged MAIN");
                bIsRunning = false;
                preload.setNumBpr(null);
                preload.setDateBprValue(null);
                preload.setPortCom(null);
                preload.setPerCentProgressData(0);
                preload.setBprIsUnplugged(false);
                preload.setBufferFlashTotEmpty();
                preload.setNbRemainingErase(null);
                preload.setbComPortIsOpen(false);
                preload.setRecordsEmpty();
                //changer la view (pas de bpr detected)
                preloadVars = { 'comPort': null,
                    'numBpr': "0",
                    'dateBpr': null };
                if (win !== null)
                    win.webContents.send('get-vars-app', preloadVars);
                //Re lancer le code ?
                beginGetData();
            }
        }
    }, 1000);
    electron_1.ipcMain.on('bpr-unplugged', function (event, arg) {
        log.info("IPCMAIN GET BPR Unplugged");
        var tUnpluggedBpr = setInterval(function () {
            if (preload.getBprIsUnplugged().bBprUnplugged === true) {
                log.warn("BPR IS UNPLUGGED");
                if (win !== null)
                    win.webContents.send('get-bpr-unplugged', { 'bool': preload.getBprIsUnplugged().bBprUnplugged });
                clearInterval(tUnpluggedBpr);
            }
        }, 200);
    });
    electron_1.ipcMain.on('bpr-empty', function (event, arg) {
        log.info("IPCMAIN GET BPR empty");
        //console.log("dans ipc main bpt empty")
        //console.log("bpr is empty : ", preload.getBprIsEmpty().bBprEmpty)
        var tFlashEmpty = setInterval(function () {
            if (preload.getBprIsEmpty().bBprEmpty !== null) {
                //console.log("dans if(preload.getBprIsEmpty().bBprEmpty !== null)")
                //console.log("preload.getRemainingErase().nbRemainingEras !== null)")
                if (win !== null)
                    win.webContents.send('get-bpr-empty', preload.getBprIsEmpty().bBprEmpty);
                clearInterval(tFlashEmpty);
            }
        }, 200);
    });
    electron_1.ipcMain.on('get-is-configured', function (event, arg) {
        log.info("IPCMAIN GET BPR Configured");
        //console.log("dans get is configured")
        //console.log("bIsConfigured MAin ipc sensync : ", bIsConfigured)
        event.returnValue = bIsConfigured;
        if (bIsConfigured === true)
            bIsConfigured = false;
    });
    electron_1.ipcMain.on('config-set-date', function (event, arg) {
        log.info("IPCMAIN SET DATE Config");
        var cptErase = 0;
        var preloadVars;
        var res;
        var messConfigContinue = "All measurement values will be erased. Do you want to continue ?\n";
        var optionsMessDialog = {
            title: "FM332Log configuration",
            message: messConfigContinue,
            type: "warning",
            buttons: ["Yes", "No"],
        };
        res = electron_1.dialog.showMessageBoxSync(win, optionsMessDialog);
        // console.log("res : ", res)
        res === 0 ? bErasing = true : bErasing = false;
        bIsRunning = true;
        if (bErasing === true) {
            preload.setNbRemainingErase(null);
            preload.setDateBpr();
            var tSetDate = setInterval(function () {
                if (preload.getRemainingErase().nbRemainingErase !== null) {
                    bIsRunning = false;
                    bIsConfigured = true;
                    preload.setRecordsEmpty();
                    preload.setBprIsEmpty(true);
                    // console.log("preload.getRemainingErase().nbRemainingEras !== null) : ", preload.getRemainingErase().nbRemainingErase)
                    if (win !== null)
                        win.webContents.send('set-config-date', preload.getRemainingErase().nbRemainingErase);
                    clearInterval(tSetDate);
                }
                else {
                    cptErase++;
                    // console.log("dans else cpt erase = ", cptErase)
                    if (cptErase >= 7) { //3.5sec sans reponse de erase dans le capteur => capteur ou cable ftdi debranché
                        //message pour dire qu'il y a eu un probleme dans la config
                        log.warn("BPR unplugged while erasing");
                        preloadVars = { 'comPort': null,
                            'numBpr': "0",
                            'dateBpr': null };
                        if (win !== null)
                            win.webContents.send('get-vars-app', preloadVars);
                        var messErase = "FM332Log had a problem while configuration.\n";
                        electron_1.dialog.showMessageBox({ title: "FM332Log configuration",
                            message: messErase,
                            type: "warning",
                            buttons: ["OK"], });
                        preload.setBprIsUnplugged(true);
                        preload.closeSerialPort();
                        clearInterval(tSetDate);
                    }
                }
            }, 500);
        }
        else {
            bIsRunning = false;
            if (win !== null)
                win.webContents.send('set-config-date', 'erase-cancelled');
        }
        // }
        // else{
        // console.log("if response dialog show config MAIN == 1")
        // win.webContents.send('valid-erase', false)
        // win.webContents.send('set-config-date', 'X')
        // bIsConfigured = false;
        // preload.setBprIsEmpty(false)
        // }
    });
    electron_1.ipcMain.on('valid-erase', function (event, arg) {
        //console.log(arg)
        event.returnValue = bErasing;
    });
    electron_1.ipcMain.on('config-get-date', function (event, arg) {
        log.info("IPCMAIN GET DATE Config");
        // console.log(arg)
        bIsRunning = true;
        preload.sendGetDateBpr();
        var tGetDate = setInterval(function () {
            if (preload.getDateBpr().dateBpr !== null && preload.getBprIsEmpty().bBprEmpty !== null) {
                bIsRunning = false;
                if (win !== null)
                    win.webContents.send('get-config-date', { 'dateBpr': preload.getDateBpr().dateBpr, 'empty': preload.getBprIsEmpty().bBprEmpty });
                clearInterval(tGetDate);
            }
        }, 500);
    });
    electron_1.ipcMain.on('get-addresses', function (event, arg) {
        event.returnValue = preload.getAddressFlashIPC();
    });
    electron_1.ipcMain.on('config-get-date-after-erase', function (event, arg) {
        log.info("IPCMAIN GET DATE Config after ERASE");
        preload.sendGetDateBprAfterErase();
        var tGetDate = setInterval(function () {
            if (preload.getDateBpr().dateBpr !== null) {
                if (win !== null)
                    win.webContents.send('get-config-date-after-erase', { 'dateBpr': preload.getDateBpr().dateBpr });
                clearInterval(tGetDate);
            }
        }, 500);
    });
    electron_1.ipcMain.on('save-in-files', function (event, arg) {
        log.info("IPCMAIN SAVE RECORDS IN Files");
        event.returnValue = preload.saveInFiles(arg, BASE_PATH); //only for prod
        //event.returnValue = preload.saveInFiles(arg, __dirname)//For debug local
    });
    electron_1.ipcMain.on('open-files', function (event, arg) {
        log.info("IPCMAIN OPEN FLUD2 File");
        preload.openFile(BASE_PATH); //only for prod
        //preload.openFile(__dirname) //For debug local
        var t = setInterval(function () {
            preload.getOpenedFile().openedRecord;
            if (preload.getOpenedFile().openedRecord !== null) {
                if (win !== null)
                    win.webContents.send('get-open-file', preload.getOpenedFile().openedRecord);
                clearInterval(t);
            }
        }, 500);
    });
    electron_1.ipcMain.on('save-csv-file', function (event, arg) {
        log.info("IPCMAIN SAVE CSV File");
        event.returnValue = preload.saveCSV(arg[0], arg[1], arg[2], arg[3], BASE_PATH);
        //event.returnValue = preload.saveCSV(arg[0], arg[1], arg[2], arg[3], __dirname)
    });
}
catch (e) {
    // Catch Error
    log.error("ERROR MAINWINDOW");
    // throw e;
}
var bIsRunning = false;
var bReconnectPortCom = false;
var bErasing = false;
var bIsConfigured = false; //on met a true si on a BIEN configurer le bpr (erase)
function beginGetData() {
    log.info("BEGIN Get VARS");
    var cptTserial = 0;
    var cptTbpr = 0;
    var preloadVars = null;
    preload.connectSerialPort();
    var tSerial = setInterval(function () {
        cptTserial++;
        if (preload.getVars().comPort !== null) { //Cable FTDI connecte
            log.info("FTDI cable is connected");
            // bIsRunning = true;
            clearInterval(tSerial);
            preload.connectPortRunApp(preload.getVars().comPort);
            var tConnectBpr = setInterval(function () {
                cptTbpr++;
                if (preload.getVars().numBpr !== null) { //Bpr connecte
                    log.info("BPR is connected");
                    preload.setBprIsUnplugged(false);
                    if (win !== null)
                        win.webContents.send('get-bpr-unplugged', { 'bool': false });
                    // console.log("clear tConnectBpr")
                    bIsRunning = true;
                    clearInterval(tConnectBpr);
                    //Pour view HOME
                    preloadVars = { 'comPort': null,
                        'numBpr': null,
                        'dateBpr': null };
                    if (win !== null)
                        win.webContents.send('get-vars-app', preloadVars);
                    var t = setInterval(function () {
                        if (preload.getVars().dateBpr !== null) {
                            bIsRunning = false;
                            if (win !== null)
                                win.webContents.send('get-vars-app', preload.getVars());
                            clearInterval(t);
                        }
                        else {
                            //console.log("dans else lancer get date bpr begin")
                            preload.getDateBprBegin();
                        }
                    }, 300);
                }
                else {
                    // console.log("dans else run connect")
                    if (cptTbpr >= 2) {
                        if (!bReconnectPortCom && !bIsRunning) {
                            // console.log("if(!bReconnectPortCom && !bIsRunning)")
                            preload.reconnetPortCom();
                            bReconnectPortCom = true;
                        }
                        if (preload.getVars().comPort !== null) {
                            // console.log("port com !== null)")
                            bReconnectPortCom = false;
                            preload.connectPortRunApp(preload.getVars().comPort);
                            preload.setBprIsUnplugged(true);
                            preload.closeSerialPort();
                            if (win !== null)
                                win.webContents.send('get-bpr-unplugged', { 'bool': true });
                            preloadVars = { 'comPort': null,
                                'numBpr': "0",
                                'dateBpr': null };
                            if (win !== null)
                                win.webContents.send('get-vars-app', preloadVars);
                        }
                        else { //port com n'est plus connecte au PC
                            // console.log("dans ELSE donc port com == null)")
                            if (!bIsRunning) {
                                preload.setBprIsUnplugged(true);
                                bIsRunning = true;
                                clearInterval(tConnectBpr);
                            }
                        }
                    }
                }
            }, 2000);
        }
        else {
            preload.connectSerialPort();
            preload.setBprIsUnplugged(true);
            // preload.closeSerialPort();
            // console.log("before win send : ", preload.getBprIsUnplugged().bBprUnplugged)
            if (win !== null)
                win.webContents.send('get-bpr-unplugged', { 'bool': true });
            //console.log("in else tserial")
            if (cptTserial >= 2) {
                preloadVars = { 'comPort': null,
                    'numBpr': "0",
                    'dateBpr': null };
                if (win !== null)
                    win.webContents.send('get-vars-app', preloadVars);
            }
        }
    }, 200);
}
function getDataFlash() {
    log.info("GET DATA Function");
    //console.log("bpr is unplmuged : ", preload.getBprIsUnplugged().bBprUnplugged)
    var cptTserial = 0;
    var cptTbpr = 0;
    var preloadVars = null;
    preload.sendGetDataFlashBpr();
    bIsRunning = true;
    var tGetDataFlash = setInterval(function () {
        //console.log("tGetDataFlash")
        //console.log("preload.getBprIsEmpty().bBprEmpty : ", preload.getBprIsEmpty().bBprEmpty)
        if (preload.getPerCentProgressBar().perCentProgressData <= 100 && preload.getPerCentProgressBar().perCentProgressData > 0 && !preload.getBprIsUnplugged().bBprUnplugged) {
            if (win !== null)
                win.webContents.send('get-percent-progress', preload.getPerCentProgressBar().perCentProgressData);
        }
        if (preload.getBprIsEmpty().bBprEmpty === true) {
            //console.log("dans get bpr is empty de main est true")
            //console.log("% : ", preload.getPerCentProgressBar().perCentProgressData)
            if (preload.getPerCentProgressBar().perCentProgressData == 100) {
                clearInterval(tGetDataFlash);
                preload.setBprIsUnplugged(false);
                //console.log("in data IS null dans bpr is empty de function get data flash")
                //console.log("records dans bpr is empty de function get data flash : ",preload.getRecords())
                bIsRunning = false;
                if (win !== null)
                    win.webContents.send('data-flash', preload.getRecords());
                // clearInterval(t)
            }
        }
        else if (preload.getBprIsEmpty().bBprEmpty === false) {
            //console.log("dans get bpr is empty de main est false")
            //console.log("preload.getPerCentProgressBar().perCentProgressData == 100 : ", preload.getPerCentProgressBar().perCentProgressData == 100)
            //console.log("preload.getPerCentProgressBar().perCentProgressData : ", preload.getPerCentProgressBar().perCentProgressData)
            //console.log("preload.getRecords().reords!==null : ", preload.getRecords().reords!==null)
            if (preload.getPerCentProgressBar().perCentProgressData == 100 && preload.getRecords().reords !== null && preload.getRecordsCreated().bRecordsCreated) {
                clearInterval(tGetDataFlash);
                // console.log("if perCentProgressData == 100 && preload.getRecords().reords!==null ON ENVOIE REPONSE ")
                //console.log("records dans bpr is NOT empty de function get data flash : ",preload.getRecords())
                bIsRunning = false;
                if (win !== null)
                    win.webContents.send('data-flash', preload.getRecords());
                // clearInterval(t)
            }
        }
        if (preload.getBprIsUnplugged().bBprUnplugged === true || preload.getVars().comPort === null) {
            //console.log("dans bpr is unplugged de main fonction get data flash ")
            clearInterval(tGetDataFlash);
            // preload.closeSerialPort()
        }
        // if(preload.getPerCentProgressBar().perCentProgressData == 100 && preload.getRecords().reords!==null){
        //   console.log("in date not null ")
        //   console.log(preload.getRecords())
        //   bIsRunning = false;
        //   win.webContents.send('data-flash', preload.getRecords())
        //   clearInterval(t)
        // }
    }, 400);
}
//# sourceMappingURL=main.js.map